searchData={"items":[{"type":"module","title":"KubeProbex","doc":"Kube Probex is a lightweight and flexible Elixir library designed to help define HTTP probes in Kubernetes\nfor applications built using the Phoenix framework. It leverages Phoenix Plug to integrate seamlessly into your\nweb application, making it easy to ensure that your services remain healthy and responsive in Kubernetes environments.","ref":"KubeProbex.html"},{"type":"module","title":"Features - KubeProbex","doc":"- **Simple Integration**: Add liveness, readiness, and startup probes to your Phoenix app with minimal configuration.\n- **Customizable Checks**: Define your own liveness, readiness, and startup probes logic to suit your application's needs.\n- **Kubernetes-Ready**: Built with Kubernetes probe endpoints in mind.\n- **Lightweight**: Minimal dependencies and easy to use.","ref":"KubeProbex.html#module-features"},{"type":"module","title":"Installation - KubeProbex","doc":"Add `kube_probex` to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:kube_probex, \"~> 0.1.0\"}\n]\nend\n```\n\nThen, fetch the dependencies:\n\n```bash\nmix deps.get\n```","ref":"KubeProbex.html#module-installation"},{"type":"module","title":"Usage - KubeProbex","doc":"","ref":"KubeProbex.html#module-usage"},{"type":"module","title":"Adding the Plugs to Your Phoenix Endpoint or Router - KubeProbex","doc":"To use `kube_probex`, add it to your Phoenix endpoint or router as a plug:\n\n<!-- tabs-open -->","ref":"KubeProbex.html#module-adding-the-plugs-to-your-phoenix-endpoint-or-router"},{"type":"module","title":"Liveness - KubeProbex","doc":"```elixir\n# lib/my_app_web/endpoint.ex\n\ndefmodule MyAppWeb.Endpoint do\nuse Phoenix.Endpoint, otp_app: :my_app_web\n\nplug KubeProbex.Plug.Liveness, path: ~w(/_health /_healthz)\nend\n```\n\nThis will expose:\n  - A liveness probe endpoint at `/_health` and `/_healthz` paths.","ref":"KubeProbex.html#module-liveness"},{"type":"module","title":"Readiness - KubeProbex","doc":"```elixir\n# lib/my_app_web/endpoint.ex\n\ndefmodule MyAppWeb.Endpoint do\nuse Phoenix.Endpoint, otp_app: :my_app_web\n\nplug KubeProbex.Plug.Readiness, path: ~w(/_ready /_readyz), otp_apps: [:my_app]\nend\n```\n\nThis will expose:\n  - A readiness probe endpoint at `/_ready` and `/_readyz` paths.\n\n<!-- tabs-close -->\n\n> #### Note {: .tip}\n>\n> Check the **Available Plugs** section in the sidebar for a list of all available plugs.","ref":"KubeProbex.html#module-readiness"},{"type":"module","title":"Customizing Probe Checks - KubeProbex","doc":"You can define custom probe checks by configuring `kube_probex`. Add a module implementing one of the\ncheck behaviours:\n\n```elixir\ndefmodule MyApp.LivenessCheck do\n  @behaviour KubeProbex.Check.Liveness\n\n  alias Plug.Conn\n\n  @impl true\n  def check(conn, _liveness_plug_opts) do\n    if some_condition() do\n      conn\n      |> Conn.put_resp_content_type(\"application/json\")\n      |> Conn.send_resp(200, ~s({\"status\": \"ok\"}))\n    else\n      conn\n      |> Conn.put_resp_content_type(\"application/json\")\n      |> Conn.send_resp(500, ~s({\"status\": \"error\"}))\n    end\n  end\n\n  defp some_condition do\n    # Your custom logic here\n    true\n  end\nend\n```\n\nThen, configure `kube_probex` to use your custom check in `config/config.exs`:\n\n```elixir\nconfig :kube_probex, liveness_check: MyApp.LivenessCheck\n```\n\n#### Kubernetes Configuration\n\nIn your Kubernetes deployment manifest, configure the liveness probe to point to the exposed endpoint:\n\n```yaml\nlivenessProbe:\nhttpGet:\n  path: /_health\n  port: 4000\ninitialDelaySeconds: 5\nperiodSeconds: 10\n```\n\n> #### Note {: .tip}\n>\n> Check the **Behaviours** section in the sidebar for a list of all behaviours.","ref":"KubeProbex.html#module-customizing-probe-checks"},{"type":"module","title":"KubeProbex.Plug.PathValidator","doc":"A helper module for validating HTTP paths of incoming Kubernetes probe requests.\n\nIt provides functionality to check if an HTTP request matches the expected path\nfor a Kubernetes probe (e.g., liveness, readiness).\n\n> #### **Note** {: .warning}\n>\n> This is an internal module and is not intended for direct use.","ref":"KubeProbex.Plug.PathValidator.html"},{"type":"function","title":"KubeProbex.Plug.PathValidator.valid_path?/3","doc":"Validates if the request's path matches the expected path for a Kubernetes probe.\n\nThis function checks the `request_path` of an incoming `Plug.Conn` against a list\nof allowed paths. If a custom path is provided in the `plug_opts` argument, it will use\nthat for validation. Otherwise, it falls back to the `default_path`.","ref":"KubeProbex.Plug.PathValidator.html#valid_path?/3"},{"type":"function","title":"Parameters - KubeProbex.Plug.PathValidator.valid_path?/3","doc":"- `conn` - The `%Plug.Conn{}` struct representing the incoming request.\n  - `plug_opts` - A keyword list of options passed to the probe plug, which may contain\n    a `:path` key specifying custom paths.\n  - `default_path` - A string representing the default probe path to validate against.","ref":"KubeProbex.Plug.PathValidator.html#valid_path?/3-parameters"},{"type":"function","title":"Example - KubeProbex.Plug.PathValidator.valid_path?/3","doc":"Assuming the default path:\n```elixir\n  iex> conn = %Plug.Conn{request_path: \"/health/liveness\"}\n  iex> opts = []\n  iex> KubeProbex.Plug.PathValidator.valid_path?(conn, opts, \"/health/liveness\")\n  true\n```\n\nWith a customized path:\n```elixir\n  iex> conn = %Plug.Conn{request_path: \"/custom/liveness\"}\n  iex> opts = [path: [\"/custom/liveness\"]]\n  iex> KubeProbex.Plug.PathValidator.valid_path?(conn, opts, \"/health/liveness\")\n  true\n```","ref":"KubeProbex.Plug.PathValidator.html#valid_path?/3-example"},{"type":"module","title":"KubeProbex.Plug.Liveness","doc":"A plug for handling Kubernetes HTTP liveness probe requests.\n\nThis module integrates with Phoenix applications to define a liveness probe\nendpoint. It validates the incoming request's path and executes the configured liveness\ncheck logic.","ref":"KubeProbex.Plug.Liveness.html"},{"type":"module","title":"Default Behavior - KubeProbex.Plug.Liveness","doc":"- The default path for liveness probes is `\"/healthz\"`.\n- The liveness check is performed using the `KubeProbex.Check.Liveness` behaviour.\n- If the incoming request's path does not match the expected path, the request is passed\n  through unaltered.","ref":"KubeProbex.Plug.Liveness.html#module-default-behavior"},{"type":"module","title":"Configuration - KubeProbex.Plug.Liveness","doc":"You can customize the path for the liveness probe by providing a `:path` option\nwhen configuring this plug. If no custom path is provided, the default path `\"/healthz\"`\nwill be used.","ref":"KubeProbex.Plug.Liveness.html#module-configuration"},{"type":"module","title":"Example - KubeProbex.Plug.Liveness","doc":"Add the liveness plug to your router or endpoint to define the liveness probe:\n\n  ```elixir\n  defmodule MyAppWeb.Router do\n    use Phoenix.Endpoint, otp_app: :my_app_web\n\n    plug KubeProbex.Plug.Liveness, path: ~w(/_health /_healthz)\n  end\n  ```","ref":"KubeProbex.Plug.Liveness.html#module-example"},{"type":"module","title":"KubeProbex.Plug.Readiness","doc":"A plug for handling Kubernetes HTTP readiness probe requests.\n\nThis module integrates with Phoenix applications to define a readiness probe\nendpoint. It validates the incoming request's path and executes the configured readiness\ncheck logic.","ref":"KubeProbex.Plug.Readiness.html"},{"type":"module","title":"Default Behavior - KubeProbex.Plug.Readiness","doc":"- The default path for readiness probes is `\"/readyz\"`.\n- The readiness check is performed using the `KubeProbex.Check.Readiness` behaviour implemented\n  by `KubeProbex.Check.EctoReady` by default. Check its documentation for more details on how to use it.\n- If the incoming request's path does not match the expected path, the request is passed\n  through unaltered.","ref":"KubeProbex.Plug.Readiness.html#module-default-behavior"},{"type":"module","title":"Configuration - KubeProbex.Plug.Readiness","doc":"You can customize the path for the readiness probe by providing a `:path` option\nwhen configuring this plug. If no custom path is provided, the default path `\"/readyz\"`\nwill be used.","ref":"KubeProbex.Plug.Readiness.html#module-configuration"},{"type":"module","title":"Example - KubeProbex.Plug.Readiness","doc":"Add the readiness plug to your router or endpoint to define the readiness probe:\n\n```elixir\ndefmodule MyAppWeb.Router do\n  use Phoenix.Endpoint, otp_app: :my_app_web\n\n  plug KubeProbex.Plug.Readiness, path: ~w(/_ready /_readyz), otp_apps: [:my_app_web]\nend\n```","ref":"KubeProbex.Plug.Readiness.html#module-example"},{"type":"behaviour","title":"KubeProbex.Check.Liveness","doc":"Defines the behaviour for implementing HTTP liveness checks.\n\nThis module provides a common contract for handling liveness probe requests\nin a Kubernetes environment. Liveness checks are used by Kubernetes to determine\nif the application is healthy.","ref":"KubeProbex.Check.Liveness.html"},{"type":"behaviour","title":"Behaviour - KubeProbex.Check.Liveness","doc":"To implement a custom liveness check, a module must implement the `check/2` callback, which:\n\n- Processes the HTTP request represented by a `Plug.Conn`.\n- Determines and sets the appropriate HTTP response status, headers, and body.","ref":"KubeProbex.Check.Liveness.html#module-behaviour"},{"type":"behaviour","title":"Default Implementation - KubeProbex.Check.Liveness","doc":"By default, the `KubeProbex.Check.Heartbeat` module is used to handle liveness checks.","ref":"KubeProbex.Check.Liveness.html#module-default-implementation"},{"type":"behaviour","title":"Custom Readiness Checks - KubeProbex.Check.Liveness","doc":"You can override the default liveness check implementation by configuring your custom module in your application\nunder the `:kube_probex` key:\n\n```elixir\nconfig :kube_probex, :readiness_check, MyCustomLivenessCheck\n```\n\nYour custom module must implement the `KubeProbex.Check.Liveness` behaviour by defining the `check/2` function.","ref":"KubeProbex.Check.Liveness.html#module-custom-readiness-checks"},{"type":"behaviour","title":"Example - KubeProbex.Check.Liveness","doc":"A basic custom implementation:\n\n```elixir\ndefmodule MyCustomLivenessCheck do\n  @behaviour KubeProbex.Check.Liveness\n\n  alias Plug.Conn\n\n  @impl true\n  def check(conn, _opts) do\n    conn\n    |> Conn.put_resp_content_type(\"application/json\")\n    |> Conn.send_resp(200, ~s({\"status\": \"ok\"}))\n  end\nend\n```","ref":"KubeProbex.Check.Liveness.html#module-example"},{"type":"function","title":"KubeProbex.Check.Liveness.check/2","doc":"Executes the liveness check logic.\n\nThis function retrives a custom adapter if its configured\nor uses the default one to processes an HTTP request for a liveness probe.\nIt takes a `Plug.Conn` struct and a list of options.\n\nThe implementation determines the response status,\ncontent type, and body.","ref":"KubeProbex.Check.Liveness.html#check/2"},{"type":"function","title":"Parameters - KubeProbex.Check.Liveness.check/2","doc":"- `conn` - The `Plug.Conn` representing the HTTP request.\n  - `opts` - A list of options provided for the liveness check plug.","ref":"KubeProbex.Check.Liveness.html#check/2-parameters"},{"type":"callback","title":"KubeProbex.Check.Liveness.check/2","doc":"","ref":"KubeProbex.Check.Liveness.html#c:check/2"},{"type":"behaviour","title":"KubeProbex.Check.Readiness","doc":"Defines the behaviour for implementing HTTP readiness checks.\n\nThis module specifies a contract for handling readiness probe requests in a Kubernetes environment.\nReadiness checks are used by Kubernetes to determine if the application is ready to serve traffic.","ref":"KubeProbex.Check.Readiness.html"},{"type":"behaviour","title":"Behaviour - KubeProbex.Check.Readiness","doc":"To implement a custom readiness check, a module must implement the `check/2` callback, which:\n\n- Processes the HTTP request represented by a `Plug.Conn`.\n- Determines and sets the appropriate HTTP response status, headers, and body.","ref":"KubeProbex.Check.Readiness.html#module-behaviour"},{"type":"behaviour","title":"Default Implementation - KubeProbex.Check.Readiness","doc":"By default, the `KubeProbex.Check.EctoReady` module is used to handle readiness checks.","ref":"KubeProbex.Check.Readiness.html#module-default-implementation"},{"type":"behaviour","title":"Custom Readiness Checks - KubeProbex.Check.Readiness","doc":"You can override the default readiness check implementation by configuring your custom module in your application\nunder the `:kube_probex` key:\n\n```elixir\nconfig :kube_probex, :readiness_check, MyCustomReadinessCheck\n```\n\nYour custom module must implement the `KubeProbex.Check.Readiness` behaviour by defining the `check/2` function.","ref":"KubeProbex.Check.Readiness.html#module-custom-readiness-checks"},{"type":"behaviour","title":"Example - KubeProbex.Check.Readiness","doc":"A basic custom implementation:\n\n```elixir\ndefmodule MyCustomReadinessCheck do\n  @behaviour KubeProbex.Check.Readiness\n\n  alias Plug.Conn\n\n  @impl true\n  def check(conn, _opts) do\n    conn\n    |> Conn.put_resp_content_type(\"application/json\")\n    |> Conn.send_resp(200, ~s({\"status\": \"ready\"}))\n  end\nend\n```","ref":"KubeProbex.Check.Readiness.html#module-example"},{"type":"function","title":"KubeProbex.Check.Readiness.check/2","doc":"Executes the readiness check logic.\n\nThis function retrives a custom adapter if its configured or uses the default one to\nprocesses an HTTP request for a readiness probe. It takes a `Plug.Conn` struct and a list of options.\n\nThe implementation determines the response status,\ncontent type, and body.","ref":"KubeProbex.Check.Readiness.html#check/2"},{"type":"function","title":"Parameters - KubeProbex.Check.Readiness.check/2","doc":"- `conn` - The `Plug.Conn` representing the HTTP request.\n  - `opts` - A list of options provided for the readiness check plug.","ref":"KubeProbex.Check.Readiness.html#check/2-parameters"},{"type":"callback","title":"KubeProbex.Check.Readiness.check/2","doc":"","ref":"KubeProbex.Check.Readiness.html#c:check/2"},{"type":"module","title":"KubeProbex.Check.EctoReady","doc":"Provides the default implementation for `KubeProbex.Check.Readiness` behaviour using Ecto.\n\nThis module defines a readiness probe handler that ensures database health by performing\nthe following checks:\n\n1. **Pending Migrations**: Checks if there are any pending migrations for the configured repositories.\n2. **Database Storage**: If there are no migrations defined, verifies if the database storage is properly created.\n\nIf any of these checks fail, the module raises appropriate exceptions to indicate the issue:\n\n- `KubeProbex.Exceptions.Ecto.PendingMigrationsError` is raised if there are pending migrations.\n- `KubeProbex.Exceptions.Ecto.DatabaseNotCreatedError` is raised if the database is not created.\n\nWhen all checks pass, the module returns an HTTP response with the following attributes:\n\n- **Status**: `200`\n- **Content-Type**: `application/json`\n- **Body**: `{\"status\": \"ready\"}`\n\nThis indicates that the application is ready to serve traffic.","ref":"KubeProbex.Check.EctoReady.html"},{"type":"module","title":"Usage - KubeProbex.Check.EctoReady","doc":"Ensure your application specifies the required `:ecto_repos` configuration.","ref":"KubeProbex.Check.EctoReady.html#module-usage"},{"type":"module","title":"Example - KubeProbex.Check.EctoReady","doc":"```elixir\nconfig :my_app, :ecto_repos, [MyApp.Repo]\n```","ref":"KubeProbex.Check.EctoReady.html#module-example"},{"type":"module","title":"Options - KubeProbex.Check.EctoReady","doc":"- `:otp_apps` - A list of OTP applications whose Ecto repositories should be checked. Each\n  application must define its Ecto repositories under the `:ecto_repos` configuration key. This option\n  should be passed when setting the `KubeProbex.Plug.Readiness` plug.","ref":"KubeProbex.Check.EctoReady.html#module-options"},{"type":"module","title":"Exemple - KubeProbex.Check.EctoReady","doc":"```elixir\ndefmodule MyAppWeb.Router do\n  use Phoenix.Endpoint, otp_app: :my_app_web\n\n  plug KubeProbex.Plug.Readiness, path: ~w(/_ready /_readyz), otp_apps: [:my_app]\nend\n```","ref":"KubeProbex.Check.EctoReady.html#module-exemple"},{"type":"module","title":"KubeProbex.Check.Heartbeat","doc":"Provides the default implementation for `KubeProbex.Check.Liveness` behaviour.\n\nThis module provides a basic liveness probe handler that always returns a response with\nthe following attributes:\n\n  - **Status**: [`200`](https://http.cat/200)\n  - **Content-Type**: `application/json`\n  - **Body**: `{\"status\": \"ok\"}`\n\nThis indicates that the application is up and running.","ref":"KubeProbex.Check.Heartbeat.html"},{"type":"exception","title":"KubeProbex.Exceptions.Ecto.DatabaseNotCreatedError","doc":"An exception raised when a database storage is not created for a specific Ecto repository.\n\nThis exception is used by the `KubeProbex.Check.EctoReady` module during readiness checks\nto signal that the required database storage has not been initialized. It provides\na clear error message to guide developers in resolving the issue.","ref":"KubeProbex.Exceptions.Ecto.DatabaseNotCreatedError.html"},{"type":"exception","title":"Attributes - KubeProbex.Exceptions.Ecto.DatabaseNotCreatedError","doc":"- `repo` - The Ecto repository for which the database storage is missing.","ref":"KubeProbex.Exceptions.Ecto.DatabaseNotCreatedError.html#module-attributes"},{"type":"exception","title":"KubeProbex.Exceptions.Ecto.PendingMigrationsError","doc":"An exception raised when there are pending database migrations for a specific Ecto repository.\n\nThis exception is used by the `KubeProbex.Check.EctoReady` module during readiness checks\nto indicate that a repository requires migrations to be run before it can be considered ready.\nIt provides a clear error message to guide developers in resolving the issue.","ref":"KubeProbex.Exceptions.Ecto.PendingMigrationsError.html"},{"type":"exception","title":"Attributes - KubeProbex.Exceptions.Ecto.PendingMigrationsError","doc":"- `repo` - The Ecto repository that has pending migrations.","ref":"KubeProbex.Exceptions.Ecto.PendingMigrationsError.html#module-attributes"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.0.0]\n\n- Liveness probe plug\n- Readines probe plug\n- Allow custom probes","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}